ConfigsManager class
Constructors
- ConfigsManager()
-
factory
Properties
- activeConfig → PublishConfig?
-
no setter
- activeConfigName → String?
-
no setter
-
configs
→ List<
PublishConfig> -
no setter
- hasConfigs → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addConfig(
PublishConfig config) → void -
backupIconsForNewConfig(
PublishConfig config) → void - Backup current icons and splash for a newly created config
-
backupKeystore(
PublishConfig config) → String - Backup the keystore file to the config directory and return the new path
-
getConfig(
String name) → PublishConfig? -
load(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeConfig(
String name) → void -
save(
) → void -
setActiveConfig(
String name, {bool restoreAssets = true}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited